# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## 0.0.1 - 2026-01-18

This is an early access, pre-alpha release. Some features are missing,
tile-interpolation is known to be broken, only a source distribution is
provided, and there is no documentation yet.
